Hi,

I've removed some 'e's from menues and ouer. It builds successfully.

It's LGPLv3+/MPL.

Christina Rossmanith

>From 96718e8fd485eab2bf261bccf7a34421b297b29a Mon Sep 17 00:00:00 2001
From: Christina Rossmanith <chrrossman...@web.de>
Date: Sat, 12 Feb 2011 21:19:41 +0100
Subject: [PATCH] fixed spelling menues -> menus

---
 svtools/source/config/menuoptions.cxx |   46 ++++++++++++++++----------------
 1 files changed, 23 insertions(+), 23 deletions(-)

diff --git a/svtools/source/config/menuoptions.cxx b/svtools/source/config/menuoptions.cxx
index a12f1e0..4e814a7 100644
--- a/svtools/source/config/menuoptions.cxx
+++ b/svtools/source/config/menuoptions.cxx
@@ -62,13 +62,13 @@ using namespace ::com::sun::star::uno	;
 
 #define	PROPERTYNAME_DONTHIDEDISABLEDENTRIES	OUString(RTL_CONSTASCII_USTRINGPARAM("DontHideDisabledEntry"	))
 #define	PROPERTYNAME_FOLLOWMOUSE				OUString(RTL_CONSTASCII_USTRINGPARAM("FollowMouse"				))
-#define PROPERTYNAME_SHOWICONSINMENUES          OUString(RTL_CONSTASCII_USTRINGPARAM("ShowIconsInMenues"        ))
-#define PROPERTYNAME_SYSTEMICONSINMENUES        OUString(RTL_CONSTASCII_USTRINGPARAM("IsSystemIconsInMenus"     ))
+#define PROPERTYNAME_SHOWICONSINMENUS           OUString(RTL_CONSTASCII_USTRINGPARAM("ShowIconsInMenus"         ))
+#define PROPERTYNAME_SYSTEMICONSINMENUS         OUString(RTL_CONSTASCII_USTRINGPARAM("IsSystemIconsInMenus"     ))
 
 #define	PROPERTYHANDLE_DONTHIDEDISABLEDENTRIES	0
 #define	PROPERTYHANDLE_FOLLOWMOUSE				1
-#define PROPERTYHANDLE_SHOWICONSINMENUES        2
-#define PROPERTYHANDLE_SYSTEMICONSINMENUES      3
+#define PROPERTYHANDLE_SHOWICONSINMENUS         2
+#define PROPERTYHANDLE_SYSTEMICONSINMENUS       3
 
 #define PROPERTYCOUNT                           4
 
@@ -147,8 +147,8 @@ class SvtMenuOptions_Impl : public ConfigItem
 
         /*-****************************************************************************************************//**
             @short		access method to get internal values
-            @descr		These method give us a chance to regulate acces to ouer internal values.
-                        It's not used in the moment - but it's possible for the feature!
+            @descr		These methods give us a chance to regulate access to our internal values.
+                        It's not used in the moment - but it's possible for the feature (future?)!
 
             @seealso	-
 
@@ -201,7 +201,7 @@ class SvtMenuOptions_Impl : public ConfigItem
     private:
 
         /*-****************************************************************************************************//**
-            @short		return list of fix key names of ouer configuration management which represent oue module tree
+            @short		return list of fix key names of our configuration management which represent our module tree
             @descr		These methods return a static const list of key names. We need it to get needed values from our
                         configuration management.
 
@@ -250,7 +250,7 @@ SvtMenuOptions_Impl::SvtMenuOptions_Impl()
         bMenuIcons = m_nMenuIcons ? sal_True : sal_False;
     }
 
     // Copy values from list in right order to ouer internal member.
     sal_Int32 nPropertyCount	=	seqValues.getLength()	;
     sal_Int32 nProperty			=	0						;
     for( nProperty=0; nProperty<nPropertyCount; ++nProperty )
@@ -271,12 +271,12 @@ SvtMenuOptions_Impl::SvtMenuOptions_Impl()
                                                                 seqValues[nProperty] >>= m_bFollowMouse;
                                                             }
                                                             break;
-            case PROPERTYHANDLE_SHOWICONSINMENUES       :   {
-                                                                DBG_ASSERT(!(seqValues[nProperty].getValueTypeClass()!=TypeClass_BOOLEAN), "SvtMenuOptions_Impl::SvtMenuOptions_Impl()\nWho has changed the value type of \"Office.Common\\View\\Menu\\ShowIconsInMenues\"?" );
+            case PROPERTYHANDLE_SHOWICONSINMENUS        :   {
+                                                                DBG_ASSERT(!(seqValues[nProperty].getValueTypeClass()!=TypeClass_BOOLEAN), "SvtMenuOptions_Impl::SvtMenuOptions_Impl()\nWho has changed the value type of \"Office.Common\\View\\Menu\\ShowIconsInMenus\"?" );
                                                                 seqValues[nProperty] >>= bMenuIcons;
                                                             }
                                                             break;
-            case PROPERTYHANDLE_SYSTEMICONSINMENUES		:   {
+            case PROPERTYHANDLE_SYSTEMICONSINMENUS	 	:   {
                                                                 DBG_ASSERT(!(seqValues[nProperty].getValueTypeClass()!=TypeClass_BOOLEAN), "SvtMenuOptions_Impl::SvtMenuOptions_Impl()\nWho has changed the value type of \"Office.Common\\View\\Menu\\IsSystemIconsInMenus\"?" );
                                                                 seqValues[nProperty] >>= bSystemMenuIcons;
                                                             }
@@ -331,12 +331,12 @@ void SvtMenuOptions_Impl::Notify( const Sequence< OUString >& seqPropertyNames )
             DBG_ASSERT(!(seqValues[nProperty].getValueTypeClass()!=TypeClass_BOOLEAN), "SvtMenuOptions_Impl::Notify()\nWho has changed the value type of \"Office.Common\\View\\Menu\\FollowMouse\"?" );
             seqValues[nProperty] >>= m_bFollowMouse;
         }
-        else if( seqPropertyNames[nProperty] == PROPERTYNAME_SHOWICONSINMENUES )
+        else if( seqPropertyNames[nProperty] == PROPERTYNAME_SHOWICONSINMENUS )
         {
-            DBG_ASSERT(!(seqValues[nProperty].getValueTypeClass()!=TypeClass_BOOLEAN), "SvtMenuOptions_Impl::SvtMenuOptions_Impl()\nWho has changed the value type of \"Office.Common\\View\\Menu\\ShowIconsInMenues\"?" );
+            DBG_ASSERT(!(seqValues[nProperty].getValueTypeClass()!=TypeClass_BOOLEAN), "SvtMenuOptions_Impl::SvtMenuOptions_Impl()\nWho has changed the value type of \"Office.Common\\View\\Menu\\ShowIconsInMenus\"?" );
             bMenuSettingsChanged |= seqValues[nProperty] >>= bMenuIcons;
         }
-        else if( seqPropertyNames[nProperty] == PROPERTYNAME_SYSTEMICONSINMENUES )
+        else if( seqPropertyNames[nProperty] == PROPERTYNAME_SYSTEMICONSINMENUS )
         {
             DBG_ASSERT(!(seqValues[nProperty].getValueTypeClass()!=TypeClass_BOOLEAN), "SvtMenuOptions_Impl::SvtMenuOptions_Impl()\nWho has changed the value type of \"Office.Common\\View\\Menu\\IsSystemIconsInMenus\"?" );
             bMenuSettingsChanged |= seqValues[nProperty] >>= bSystemMenuIcons;
@@ -377,12 +377,12 @@ void SvtMenuOptions_Impl::Commit()
                                                             }
                                                             break;
             //Output cache of current setting as possibly modified by System Theme for older version
-            case PROPERTYHANDLE_SHOWICONSINMENUES       :   {
+            case PROPERTYHANDLE_SHOWICONSINMENUS        :   {
                                                                 sal_Bool bValue = (sal_Bool)(Application::GetSettings().GetStyleSettings().GetUseImagesInMenus());
                                                                 seqValues[nProperty] <<= bValue;
                                                             }
                                                             break;
-            case PROPERTYHANDLE_SYSTEMICONSINMENUES		:   {
+            case PROPERTYHANDLE_SYSTEMICONSINMENUS		:   {
                                                                 sal_Bool bValue = (m_nMenuIcons == 2 ? sal_True : sal_False) ;
                                                                 seqValues[nProperty] <<= bValue;
                                                             }
@@ -403,8 +403,8 @@ Sequence< OUString > SvtMenuOptions_Impl::impl_GetPropertyNames()
     {
         PROPERTYNAME_DONTHIDEDISABLEDENTRIES	,
         PROPERTYNAME_FOLLOWMOUSE				,
-        PROPERTYNAME_SHOWICONSINMENUES			,
-        PROPERTYNAME_SYSTEMICONSINMENUES
+        PROPERTYNAME_SHOWICONSINMENUS			,
+        PROPERTYNAME_SYSTEMICONSINMENUS
     };
     // Initialize return sequence with these list ...
     static const Sequence< OUString > seqPropertyNames( pProperties, PROPERTYCOUNT );
@@ -444,9 +444,9 @@ SvtMenuOptions::SvtMenuOptions()
 {
     // Global access, must be guarded (multithreading!).
     MutexGuard aGuard( GetOwnStaticMutex() );
     // Increase ouer refcount ...
     ++m_nRefCount;
     // ... and initialize ouer data container only if it not already!
     if( m_pDataContainer == NULL )
     {
         RTL_LOGFILE_CONTEXT(aLog, "svtools ( ??? ) ::SvtMenuOptions_Impl::ctor()");
@@ -463,10 +463,10 @@ SvtMenuOptions::~SvtMenuOptions()
 {
     // Global access, must be guarded (multithreading!)
     MutexGuard aGuard( GetOwnStaticMutex() );
     // Decrease ouer refcount.
     --m_nRefCount;
     // If last instance was deleted ...
     // we must destroy ouer static data container!
     if( m_nRefCount <= 0 )
     {
         delete m_pDataContainer;
@@ -541,7 +541,7 @@ Mutex& SvtMenuOptions::GetOwnStaticMutex()
         // ... we must create a new one. Protect follow code with the global mutex -
         // It must be - we create a static variable!
         MutexGuard aGuard( Mutex::getGlobalMutex() );
-        // We must check our pointer again - because it can be that another instance of ouer class will be fastr then these!
+        // We must check our pointer again - because it can be that another instance of our class will be faster than these!
         if( pMutex == NULL )
         {
             // Create the new mutex and set it for return on static variable.
@@ -250,7 +250,7 @@ SvtMenuOptions_Impl::SvtMenuOptions_Impl()
     }
 
-    // Copy values from list in right order to ouer internal member.
+    // Copy values from list in right order to our internal member.
     sal_Int32 nPropertyCount	=	seqValues.getLength()	;
     sal_Int32 nProperty			=	0						;
@@ -444,9 +444,9 @@ SvtMenuOptions::SvtMenuOptions()
     // Global access, must be guarded (multithreading!).
     MutexGuard aGuard( GetOwnStaticMutex() );
-    // Increase ouer refcount ...
+    // Increase our refcount ...
     ++m_nRefCount;
@@ -444,9 +444,9 @@ SvtMenuOptions::SvtMenuOptions()
     ++m_nRefCount;
-    // ... and initialize ouer data container only if it not already!
+    // ... and initialize our data container only if it not already!
     if( m_pDataContainer == NULL )
     {
@@ -463,10 +463,10 @@ SvtMenuOptions::~SvtMenuOptions()
     // Global access, must be guarded (multithreading!)
     MutexGuard aGuard( GetOwnStaticMutex() );
-    // Decrease ouer refcount.
+    // Decrease our refcount.
     --m_nRefCount;
     // If last instance was deleted ...
@@ -463,10 +463,10 @@ SvtMenuOptions::~SvtMenuOptions()
     --m_nRefCount;
     // If last instance was deleted ...
-    // we must destroy ouer static data container!
+    // we must destroy our static data container!
     if( m_nRefCount <= 0 )
     {
-- 
1.7.0.4


>From 4a220e21e2bef9da74f30554a83e87386366d835 Mon Sep 17 00:00:00 2001
From: Christina Rossmanith <chrrossman...@web.de>
Date: Sat, 12 Feb 2011 21:09:31 +0100
Subject: [PATCH] fixed spelling menues -> menus

---
 .../bf_svtools/source/config/svt_menuoptions.cxx   |   36 ++++++++++----------
 1 files changed, 18 insertions(+), 18 deletions(-)

diff --git a/binfilter/bf_svtools/source/config/svt_menuoptions.cxx b/binfilter/bf_svtools/source/config/svt_menuoptions.cxx
index ab62c00..9144f5e 100644
--- a/binfilter/bf_svtools/source/config/svt_menuoptions.cxx
+++ b/binfilter/bf_svtools/source/config/svt_menuoptions.cxx
@@ -66,11 +66,11 @@ namespace binfilter
 
 #define	PROPERTYNAME_DONTHIDEDISABLEDENTRIES	OUString(RTL_CONSTASCII_USTRINGPARAM("DontHideDisabledEntry"	))
 #define	PROPERTYNAME_FOLLOWMOUSE				OUString(RTL_CONSTASCII_USTRINGPARAM("FollowMouse"				))
-#define PROPERTYNAME_SHOWICONSINMENUES          OUString(RTL_CONSTASCII_USTRINGPARAM("ShowIconsInMenues"        ))
+#define PROPERTYNAME_SHOWICONSINMENUS           OUString(RTL_CONSTASCII_USTRINGPARAM("ShowIconsInMenus"         ))
 
 #define	PROPERTYHANDLE_DONTHIDEDISABLEDENTRIES	0
 #define	PROPERTYHANDLE_FOLLOWMOUSE				1
-#define PROPERTYHANDLE_SHOWICONSINMENUES        2
+#define PROPERTYHANDLE_SHOWICONSINMENUS         2
 
 #define PROPERTYCOUNT                           3
 
@@ -142,9 +142,9 @@ class SvtMenuOptions_Impl : public ConfigItem
         //---------------------------------------------------------------------------------------------------------
 
         /*-****************************************************************************************************//**
-            @short		access method to get internal values
-            @descr		These method give us a chance to regulate acces to ouer internal values.
-                        It's not used in the moment - but it's possible for the feature!
+            @short		access methods to get internal values
+            @descr		These methods give us a chance to regulate access to our internal values.
+                        It's not used in the moment - but it's possible for the feature (future?)!
 
             @seealso	-
 
@@ -191,7 +191,7 @@ class SvtMenuOptions_Impl : public ConfigItem
     private:
 
         /*-****************************************************************************************************//**
-            @short		return list of fix key names of ouer configuration management which represent oue module tree
+            @short		return list of fix key names of our configuration management which represent our module tree
             @descr		These methods return a static const list of key names. We need it to get needed values from our
                         configuration management.
 
@@ -230,7 +230,7 @@ SvtMenuOptions_Impl::SvtMenuOptions_Impl()
     // Follow assignment use order of values in relation to our list of key names!
     DBG_ASSERT( !(seqNames.getLength()!=seqValues.getLength()), "SvtMenuOptions_Impl::SvtMenuOptions_Impl()\nI miss some values of configuration keys!\n" );
 
     // Copy values from list in right order to ouer internal member.
     sal_Int32 nPropertyCount	=	seqValues.getLength()	;
     sal_Int32 nProperty			=	0						;
     for( nProperty=0; nProperty<nPropertyCount; ++nProperty )
@@ -251,8 +251,8 @@ SvtMenuOptions_Impl::SvtMenuOptions_Impl()
                                                                 seqValues[nProperty] >>= m_bFollowMouse;
                                                             }
                                                             break;
-            case PROPERTYHANDLE_SHOWICONSINMENUES       :   {
-                                                                DBG_ASSERT(!(seqValues[nProperty].getValueTypeClass()!=TypeClass_BOOLEAN), "SvtMenuOptions_Impl::SvtMenuOptions_Impl()\nWho has changed the value type of \"Office.Common\\View\\Menu\\ShowIconsInMenues\"?" );
+            case PROPERTYHANDLE_SHOWICONSINMENUS        :   {
+                                                                DBG_ASSERT(!(seqValues[nProperty].getValueTypeClass()!=TypeClass_BOOLEAN), "SvtMenuOptions_Impl::SvtMenuOptions_Impl()\nWho has changed the value type of \"Office.Common\\View\\Menu\\ShowIconsInMenus\"?" );
                                                                 seqValues[nProperty] >>= m_bMenuIcons;
                                                             }
                                                             break;
@@ -300,9 +300,9 @@ void SvtMenuOptions_Impl::Notify( const Sequence< OUString >& seqPropertyNames )
             DBG_ASSERT(!(seqValues[nProperty].getValueTypeClass()!=TypeClass_BOOLEAN), "SvtMenuOptions_Impl::Notify()\nWho has changed the value type of \"Office.Common\\View\\Menu\\FollowMouse\"?" );
             seqValues[nProperty] >>= m_bFollowMouse;
         }
-        if( seqPropertyNames[nProperty] == PROPERTYNAME_SHOWICONSINMENUES )
+        if( seqPropertyNames[nProperty] == PROPERTYNAME_SHOWICONSINMENUS )
         {
-            DBG_ASSERT(!(seqValues[nProperty].getValueTypeClass()!=TypeClass_BOOLEAN), "SvtMenuOptions_Impl::SvtMenuOptions_Impl()\nWho has changed the value type of \"Office.Common\\View\\Menu\\ShowIconsInMenues\"?" );
+            DBG_ASSERT(!(seqValues[nProperty].getValueTypeClass()!=TypeClass_BOOLEAN), "SvtMenuOptions_Impl::SvtMenuOptions_Impl()\nWho has changed the value type of \"Office.Common\\View\\Menu\\ShowIconsInMenus\"?" );
             seqValues[nProperty] >>= m_bMenuIcons;
         }
         #if OSL_DEBUG_LEVEL > 1
@@ -333,7 +333,7 @@ void SvtMenuOptions_Impl::Commit()
                                                                 seqValues[nProperty] <<= m_bFollowMouse;
                                                             }
                                                             break;
-            case PROPERTYHANDLE_SHOWICONSINMENUES       :   {
+            case PROPERTYHANDLE_SHOWICONSINMENUS       :   {
                                                                 seqValues[nProperty] <<= m_bMenuIcons;
                                                             }
                                                             break;
@@ -353,7 +353,7 @@ Sequence< OUString > SvtMenuOptions_Impl::impl_GetPropertyNames()
     {
         PROPERTYNAME_DONTHIDEDISABLEDENTRIES	,
         PROPERTYNAME_FOLLOWMOUSE				,
-        PROPERTYNAME_SHOWICONSINMENUES
+        PROPERTYNAME_SHOWICONSINMENUS
     };
     // Initialize return sequence with these list ...
     static const Sequence< OUString > seqPropertyNames( pProperties, PROPERTYCOUNT );
@@ -376,9 +376,9 @@ SvtMenuOptions::SvtMenuOptions()
 {
     // Global access, must be guarded (multithreading!).
     MutexGuard aGuard( GetOwnStaticMutex() );
     // Increase ouer refcount ...
     ++m_nRefCount;
     // ... and initialize ouer data container only if it not already!
     if( m_pDataContainer == NULL )
     {
         RTL_LOGFILE_CONTEXT(aLog, "svtools ( ??? ) ::SvtMenuOptions_Impl::ctor()");
@@ -395,10 +395,10 @@ SvtMenuOptions::~SvtMenuOptions()
 {
     // Global access, must be guarded (multithreading!)
     MutexGuard aGuard( GetOwnStaticMutex() );
     // Decrease ouer refcount.
     --m_nRefCount;
     // If last instance was deleted ...
     // we must destroy ouer static data container!
     if( m_nRefCount <= 0 )
     {
         delete m_pDataContainer;
@@ -419,7 +419,7 @@ Mutex& SvtMenuOptions::GetOwnStaticMutex()
         // ... we must create a new one. Protect follow code with the global mutex -
         // It must be - we create a static variable!
         MutexGuard aGuard( Mutex::getGlobalMutex() );
-        // We must check our pointer again - because it can be that another instance of ouer class will be fastr then these!
+        // We must check our pointer again - because it can be that another instance of our class will be faster than these!
         if( pMutex == NULL )
         {
             // Create the new mutex and set it for return on static variable.
@@ -230,7 +230,7 @@ SvtMenuOptions_Impl::SvtMenuOptions_Impl()
     DBG_ASSERT( !(seqNames.getLength()!=seqValues.getLength()), "SvtMenuOptions_Impl::SvtMenuOptions_Impl()\nI miss some values of configuration keys!\n" );
 
-    // Copy values from list in right order to ouer internal member.
+    // Copy values from list in right order to our internal member.
     sal_Int32 nPropertyCount	=	seqValues.getLength()	;
     sal_Int32 nProperty			=	0						;
@@ -376,9 +376,9 @@ SvtMenuOptions::SvtMenuOptions()
     // Global access, must be guarded (multithreading!).
     MutexGuard aGuard( GetOwnStaticMutex() );
-    // Increase ouer refcount ...
+    // Increase our refcount ...
     ++m_nRefCount;
@@ -376,9 +376,9 @@ SvtMenuOptions::SvtMenuOptions()
     ++m_nRefCount;
-    // ... and initialize ouer data container only if it not already!
+    // ... and initialize our data container only if it not already!
     if( m_pDataContainer == NULL )
     {
@@ -395,10 +395,10 @@ SvtMenuOptions::~SvtMenuOptions()
     // Global access, must be guarded (multithreading!)
     MutexGuard aGuard( GetOwnStaticMutex() );
-    // Decrease ouer refcount.
+    // Decrease our refcount.
     --m_nRefCount;
     // If last instance was deleted ...
@@ -395,10 +395,10 @@ SvtMenuOptions::~SvtMenuOptions()
     --m_nRefCount;
     // If last instance was deleted ...
-    // we must destroy ouer static data container!
+    // we must destroy our static data container!
     if( m_nRefCount <= 0 )
     {
-- 
1.7.0.4


_______________________________________________
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice

Reply via email to